Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS SSO.

Actions, resources, and condition keys for AWS SSO - Service Authorization Reference

# Actions, resources, and condition keys for AWS SSO

AWS SSO (service prefix: `sso` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS SSO
- Resource types defined by AWS SSO
- Condition keys for AWS SSO

## Actions defined by AWS SSO

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateDirectory | Grants permission to connect a directory to be used by AWS Single Sign-On | Write |  |  | ds:AuthorizeApplication
AssociateProfile | Grants permission to create an association between a directory user or group and a profile | Write |  |  |
AttachManagedPolicyToPermissionSet | Grants permission to attach an AWS managed policy to a permission set. | Permissions management | Instance* |  |
PermissionSet* |  |
CreateAccountAssignment | Grants permission to assign access to a Principal for a specified AWS account using a specified permission set. | Write | Account* |  |
Instance* |  |
PermissionSet* |  |
CreateApplicationInstance | Grants permission to add an application instance to AWS Single Sign-On | Write |  |  |
CreateApplicationInstanceCertificate | Grants permission to add a new certificate for an application instance | Write |  |  |
CreateInstanceAccessControlAttributeConfiguration | Grants permission to enable the instance for ABAC and specify the attributes | Write | Instance* |  |
CreateManagedApplicationInstance | Grants permission to add a managed application instance to AWS Single Sign-On | Write |  |  |
CreatePermissionSet | Grants permission to create a permission set | Write | Instance* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateProfile | Grants permission to create a profile for an application instance | Write |  |  |
CreateTrust | Grants permission to create a federation trust in a target account | Write |  |  |
DeleteAccountAssignment | Grants permission to delete a Principal's access from a specified AWS account using a specified permission set. | Write | Account* |  |
Instance* |  |
PermissionSet* |  |
DeleteApplicationInstance | Grants permission to delete the application instance | Write |  |  |
DeleteApplicationInstanceCertificate | Grants permission to delete an inactive or expired certificate from the application instance | Write |  |  |
DeleteInlinePolicyFromPermissionSet | Grants permission to delete the inline policy from a specified permission set. | Write | Instance* |  |
PermissionSet* |  |
DeleteInstanceAccessControlAttributeConfiguration | Grants permission to disable ABAC and remove the attributes list for the instance | Write | Instance* |  |
DeleteManagedApplicationInstance | Grants permission to delete the managed application instance | Write |  |  |
DeletePermissionSet | Grants permission to delete a permission set | Write | Instance* |  |
PermissionSet* |  |
DeletePermissionsPolicy | Grants permission to delete the permission policy associated with a permission set | Permissions management |  |  |
DeleteProfile | Grants permission to delete the profile for an application instance | Write |  |  |
DescribeAccountAssignmentCreationStatus | Grants permission to describe the status of the assignment creation request. | Read | Instance* |  |
DescribeAccountAssignmentDeletionStatus | Grants permission to describe the status of an assignment deletion request. | Read | Instance* |  |
DescribeInstanceAccessControlAttributeConfiguration | Grants permission to get the list of attributes used by the instance for ABAC | Read | Instance* |  |
DescribePermissionSet | Grants permission to describe a permission set | Read | Instance* |  |
PermissionSet* |  |
DescribePermissionSetProvisioningStatus | Grants permission to describe the status for the given Permission Set Provisioning request. | Read | Instance* |  |
DescribePermissionsPolicies | Grants permission to retrieve all the permissions policies associated with a permission set | Read |  |  |
DescribeRegisteredRegions | Grants permission to obtain the regions where your organization has enabled AWS Single Sign-on | Read |  |  |
DetachManagedPolicyFromPermissionSet | Grants permission to detach the attached AWS managed policy from the specified permission set. | Permissions management | Instance* |  |
PermissionSet* |  |
DisassociateDirectory | Grants permission to disassociate a directory to be used by AWS Single Sign-On | Write |  |  | ds:UnauthorizeApplication
DisassociateProfile | Grants permission to disassociate a directory user or group from a profile | Write |  |  |
GetApplicationInstance | Grants permission to retrieve details for an application instance | Read |  |  |
GetApplicationTemplate | Grants permission to retrieve application template details | Read |  |  |
GetInlinePolicyForPermissionSet | Grants permission to obtain the inline policy assigned to the permission set. | Read | Instance* |  |
PermissionSet* |  |
GetManagedApplicationInstance | Grants permission to retrieve details for an application instance | Read |  |  |
GetMfaDeviceManagementForDirectory | Grants permission to retrieve Mfa Device Management settings for the directory | Read |  |  |
GetPermissionSet | Grants permission to retrieve details of a permission set | Read |  |  |
GetPermissionsPolicy | Grants permission to retrieve all permission policies associated with a permission set | Read |  |  | sso:DescribePermissionsPolicies
GetProfile | Grants permission to retrieve a profile for an application instance | Read |  |  |
GetSSOStatus | Grants permission to check if AWS Single Sign-On is enabled | Read |  |  |
GetSharedSsoConfiguration | Grants permission to retrieve shared configuration for the current SSO instance | Read |  |  |
GetSsoConfiguration | Grants permission to retrieve configuration for the current SSO instance | Read |  |  |
GetTrust | Grants permission to retrieve the federation trust in a target account | Read |  |  |
ImportApplicationInstanceServiceProviderMetadata | Grants permission to update the application instance by uploading an application SAML metadata file provided by the service provider | Write |  |  |
ListAccountAssignmentCreationStatus | Grants permission to list the status of the AWS account assignment creation requests for a specified SSO instance. | List | Instance* |  |
ListAccountAssignmentDeletionStatus | Grants permission to list the status of the AWS account assignment deletion requests for a specified SSO instance. | List | Instance* |  |
ListAccountAssignments | Grants permission to list the assignee of the specified AWS account with the specified permission set. | List | Account* |  |
Instance* |  |
PermissionSet* |  |
ListAccountsForProvisionedPermissionSet | Grants permission to list all the AWS accounts where the specified permission set is provisioned. | List | Instance* |  |
PermissionSet* |  |
ListApplicationInstanceCertificates | Grants permission to retrieve all of the certificates for a given application instance | Read |  |  |
ListApplicationInstances | Grants permission to retrieve all application instances | List |  |  | sso:GetApplicationInstance
ListApplicationTemplates | Grants permission to retrieve all supported application templates | List |  |  | sso:GetApplicationTemplate
ListApplications | Grants permission to retrieve all supported applications | List |  |  |
ListDirectoryAssociations | Grants permission to retrieve details about the directory connected to AWS Single Sign-On | Read |  |  |
ListInstances | Grants permission to list the SSO Instances that the caller has access to. | List |  |  |
ListManagedPoliciesInPermissionSet | Grants permission to list the AWS managed policies that are attached to a specified permission set. | List | Instance* |  |
PermissionSet* |  |
ListPermissionSetProvisioningStatus | Grants permission to list the status of the Permission Set Provisioning requests for a specified SSO instance. | List | Instance* |  |
ListPermissionSets | Grants permission to retrieve all permission sets | List | Instance* |  |
ListPermissionSetsProvisionedToAccount | Grants permission to list all the permission sets that are provisioned to a specified AWS account. | List | Account* |  |
Instance* |  |
ListProfileAssociations | Grants permission to retrieve the directory user or group associated with the profile | Read |  |  |
ListProfiles | Grants permission to retrieve all profiles for an application instance | List |  |  | sso:GetProfile
ListTagsForResource | Grants permission to list the tags that are attached to a specified resource. | Read | Instance* |  |
PermissionSet* |  |
ProvisionPermissionSet | Grants permission to provision a specified permission set to the specified target. | Write | Account* |  |
Instance* |  |
PermissionSet* |  |
PutInlinePolicyToPermissionSet | Grants permission to attach an IAM inline policy to a permission set. | Write | Instance* |  |
PermissionSet* |  |
PutMfaDeviceManagementForDirectory | Grants permission to put Mfa Device Management settings for the directory | Write |  |  |
PutPermissionsPolicy | Grants permission to add a policy to a permission set | Permissions management |  |  |
SearchGroups | Grants permission to search for groups within the associated directory | Read |  |  | ds:DescribeDirectories
SearchUsers | Grants permission to search for users within the associated directory | Read |  |  | ds:DescribeDirectories
StartSSO | Grants permission to initialize AWS Single Sign-On | Write |  |  | organizations:DescribeOrganization organizations:EnableAWSServiceAccess
TagResource | Grants permission to associate a set of tags with a specified resource. | Tagging | Instance* |  |
PermissionSet* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to disassociate a set of tags from a specified resource. | Tagging | Instance* |  |
PermissionSet* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateApplicationInstanceActiveCertificate | Grants permission to set a certificate as the active one for this application instance | Write |  |  |
UpdateApplicationInstanceDisplayData | Grants permission to update display data of an application instance | Write |  |  |
UpdateApplicationInstanceResponseConfiguration | Grants permission to update federation response configuration for the application instance | Write |  |  |
UpdateApplicationInstanceResponseSchemaConfiguration | Grants permission to update federation response schema configuration for the application instance | Write |  |  |
UpdateApplicationInstanceSecurityConfiguration | Grants permission to update security details for the application instance | Write |  |  |
UpdateApplicationInstanceServiceProviderConfiguration | Grants permission to update service provider related configuration for the application instance | Write |  |  |
UpdateApplicationInstanceStatus | Grants permission to update the status of an application instance | Write |  |  |
UpdateDirectoryAssociation | Grants permission to update the user attribute mappings for your connected directory | Write |  |  |
UpdateInstanceAccessControlAttributeConfiguration | Grants permission to update the attributes to use with the instance for ABAC | Write | Instance* |  |
UpdateManagedApplicationInstanceStatus | Grants permission to update the status of a managed application instance | Write |  |  |
UpdatePermissionSet | Grants permission to update the permission set. | Permissions management | Instance* |  |
PermissionSet* |  |
UpdateProfile | Grants permission to update the profile for an application instance | Write |  |  |
UpdateSSOConfiguration | Grants permission to update the configuration for the current SSO instance | Write |  |  |
UpdateTrust | Grants permission to update the federation trust in a target account | Write |  |  |

## Resource types defined by AWS SSO

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
PermissionSet | `arn:$ { Partition}:sso:::permissionSet/$ { InstanceId}/$ { PermissionSetId}` | aws:ResourceTag/${TagKey}
Account | `arn:$ { Partition}:sso:::account/$ { AccountId}` |
Instance | `arn:$ { Partition}:sso:::instance/$ { InstanceId}` |

## Condition keys for AWS SSO

AWS SSO defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on the tags associated with the resource | String
aws:TagKeys | Filters actions based on the tag keys that are passed in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.